@@ -404,3 +404,58 @@ class TeacherChairLink(Base):
 
     def __str__(self):
         return f'{self.chair}: {self.teacher}'
+
+
+class Adviser(Base):
+    """
+    Модель "Эдвайзер"
+    """
+    __tablename__ = 'univer_advicer'
+
+    # Идентификатор
+    id = Column('advicer_id', Integer, primary_key=True)
+
+    # Сотрудник
+    personnel_id = Column('personal_id', ForeignKey(
+        'univer_personal.personal_id'))
+    personnel = relationship('Personnel')
+
+    # Факультет
+    faculty_id = Column(ForeignKey('univer_faculty.faculty_id'))
+    faculty = relationship('Faculty')
+
+    # Статус
+    status = Column(Integer)
+
+    # Кафедра
+    chair_id = Column(ForeignKey('univer_chair.chair_id'))
+    chair = relationship('Chair')
+
+    def __repr__(self):
+        return '<Adviser {}>'.format(self)
+
+    def __str__(self):
+        return str(self.personnel)
+
+
+class AdviserStudent(Base):
+    """
+    Модель "Связь между Adviser (Эдвайзер) и Student (Студент)"
+    """
+    __tablename__ = 'univer_advicer_student_link'
+
+    # Эдвайзер
+    adviser_id = Column('advicer_id', ForeignKey(
+        'univer_advicer.advicer_id'), primary_key=True)
+    adviser = relationship('Adviser', backref='students')
+
+    # Студент
+    student_id = Column(ForeignKey(
+        'univer_students.students_id'), primary_key=True)
+    student = relationship('Student', backref='advisers')
+
+    def __repr__(self):
+        return '<AdviserStudent {}>'.format(self)
+
+    def __str__(self):
+        return f'{adviser}: {student}'
