@@ -1,5 +1,5 @@
 import unittest
-from univer_db.models import TeacherChairLink, OfficeRegistrator, OfficeRegistratorFacultyLink
+from univer_db.models import TeacherChairLink, OfficeRegistrator, OfficeRegistratorFacultyLink, Adviser
 
 from . import Session
 
@@ -20,3 +20,13 @@ class TestOfficeRegistrator(unittest.TestCase):
 
         for faculty_links in office_registrator.faculties:
             print(f'faculty: {faculty_links.faculty}')
+
+
+class TestAdviser(unittest.TestCase):
+    def test_get_obj(self):
+        session = Session()
+        adviser = session.query(Adviser).filter(Adviser.status == 1).first()
+        print(f'adviser: {adviser}')
+
+        for adviser_student in adviser.students:
+            print(f'student: {adviser_student.student}')
